@@ -1,15 +1,12 @@
-loading = False
-
-
 class Settings(dict):
     """
-    Lazyly loaded settings.
+    Application settings, that will typically be loaded from a module.
     """
-    def __init__(self, module):
-        self.module = module
+    def __init__(self):
         self._mod = None
 
-    def load(self):
+    def load(self, module):
+        self.module = module
         if self._mod is None:
             self._mod = __import__(self.module, globals(), locals(), [], -1)
             for attr in dir(self._mod):
@@ -17,12 +14,10 @@ class Settings(dict):
                     self[attr] = getattr(self._mod, attr)
 
     def __getattr__(self, attr):
-        global loading
-        if not loading:
-            loading = True
-            self.load()
-            loading = False
         return self[attr]
 
     def __setattr__(self, attr, value):
         self[attr] = value
+
+
+settings = Settings()
